<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	if ( ! class_exists( 'WP_List_Table' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
	}

	class ZLEADSCRM_PROSPECT_Core_Analytics extends WP_List_Table {
		public $analytics_data = null;

		public $user_id = 0;

		public function __construct( $user_id ) {
			parent::__construct(
				array(
					'singular' => 'analytic',
					'plural'   => 'analytics',
					'ajax'     => false,
				)
			);

			$this->user_id = $user_id;

			$this->analytics_data = zleadscrm_get_analytics_data( $this->user_id );
		}

		public function print_overview() {
			$this->prepare_items();
			echo '<div class="zleadscrm_overview_wrap">';
			echo '<h2 class="screen-reader-text">Analytics</h2>';
			?>
			<?php
			$this->display();
			echo '</div>';
		}

		public function column_default( $user, $column_name ) {
			if ( $this->user_id == 0 ) {
				if ( class_exists( 'ZACCTMGR_Core' ) ) {
					switch ( $column_name ) {
						case 'name':
							return '<span>' . $user['name'] . '</span>';
						case 'username':
							return '<span>' . $user['username'] . '</span>';
						case 'leads':
							return '<span>' . $user['leads'] . '</span>';
						case 'bookmarks':
							return '<span>' . $user['bookmarks'] . '</span>';
						case 'search_functionality':
							return '<span>' . $user['search_functionality'] . '</span>';
						case 'export_functionality':
							return '<span>' . $user['export_functionality'] . '</span>';
						case 'search_request':
							return '<span>' . $user['search_request'] . '</span>';
						case 'basic_results':
							return '<span>' . $user['basic_results'] . '</span>';
						case 'advanced_results':
							return '<span>' . $user['advanced_results'] . '</span>';
						case 'actions':
							ob_start();
							?><p>
							<?php

							$actions['edit'] = array(
								'url'    => add_query_arg( 'user_id', $user['user_id'] ),
								'name'   => 'Edit',
								'action' => 'edit',
								'class'  => 'edit'
							);

							foreach ( $actions as $action ) {
								printf( '<a class="button tips dashicons dashicons-%s" href="%s" style="width: 35px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ) );
							}
							?>
                            </p>
							<?php
							$result_actions = ob_get_contents();
							ob_end_clean();

							return $result_actions;
					}
				} else {
					switch ( $column_name ) {
						case 'name':
							return '<span>' . $user['name'] . '</span>';
						case 'username':
							return '<span>' . $user['username'] . '</span>';
						case 'leads_created':
							return '<span>' . $user['leads_created'] . '</span>';
						case 'bookmarks':
							return '<span>' . $user['bookmarks'] . '</span>';
						case 'search_functionality':
							return '<span>' . $user['search_functionality'] . '</span>';
						case 'export_functionality':
							return '<span>' . $user['export_functionality'] . '</span>';
						case 'search_request':
							return '<span>' . $user['search_request'] . '</span>';
						case 'basic_results':
							return '<span>' . $user['basic_results'] . '</span>';
						case 'advanced_results':
							return '<span>' . $user['advanced_results'] . '</span>';
						case 'actions':
							ob_start();
							?><p>
							<?php

							$actions['edit'] = array(
								'url'    => add_query_arg( 'user_id', $user['user_id'] ),
								'name'   => 'Edit',
								'action' => 'edit',
								'class'  => 'edit'
							);

							foreach ( $actions as $action ) {
								printf( '<a class="button tips dashicons dashicons-%s" href="%s" style="width: 35px;"></a>', esc_attr( $action['class'] ), esc_url( $action['url'] ) );
							}
							?>
                            </p>
							<?php
							$result_actions = ob_get_contents();
							ob_end_clean();

							return $result_actions;
					}
				}
			} else if ( class_exists( 'ZACCTMGR_Core' ) ) {

				switch ( $column_name ) {
					case 'name':
						return '<span>' . $user['name'] . '</span>';
					case 'username':
						return '<span>' . $user['username'] . '</span>';
					case 'leads':
						return '<span>' . $user['leads'] . '</span>';
					case 'bookmarks':
						return '<span>' . $user['bookmarks'] . '</span>';
					case 'search_functionality':
						return '<span>' . $user['search_functionality'] . '</span>';
					case 'export_functionality':
						return '<span>' . $user['export_functionality'] . '</span>';
					case 'search_request':
						return '<span>' . $user['search_request'] . '</span>';
					case 'basic_results':
						return '<span>' . $user['basic_results'] . '</span>';
					case 'advanced_results':
						return '<span>' . $user['advanced_results'] . '</span>';
				}
			} else {
				switch ( $column_name ) {
					case 'name':
						return '<span>' . $user['name'] . '</span>';
					case 'username':
						return '<span>' . $user['username'] . '</span>';
					case 'leads_created':
						return '<span>' . $user['leads_created'] . '</span>';
					case 'bookmarks':
						return '<span>' . $user['bookmarks'] . '</span>';
					case 'search_functionality':
						return '<span>' . $user['search_functionality'] . '</span>';
					case 'export_functionality':
						return '<span>' . $user['export_functionality'] . '</span>';
					case 'search_request':
						return '<span>' . $user['search_request'] . '</span>';
					case 'basic_results':
						return '<span>' . $user['basic_results'] . '</span>';
					case 'advanced_results':
						return '<span>' . $user['advanced_results'] . '</span>';
				}
			}

			return '';
		}

		public function display_tablenav( $which ) {
			if ( $this->user_id == 0 ) {
				if ( $which == 'top' ) {
					$all_users      = zleadscrm_get_all_eligible_users();
					$active_users   = zleadscrm_get_active_eligible_users();
					$inactive_users = count( $all_users ) - count( $active_users );
					$status         = sanitize_text_field( $_GET['status'] );
					if ( ! isset( $status ) || $status == 'all' ) {
						$all      = 'style="color:#000; font-weight: 700;"';
						$active   = '';
						$inactive = '';
					} else if ( $status == 'inactive' ) {
						$all      = '';
						$active   = '';
						$inactive = 'style="color:#000; font-weight: 700;"';
					} else if ( $status == 'active' ) {
						$all      = '';
						$active   = 'style="color:#000; font-weight: 700;"';
						$inactive = '';
					}


					echo '<ul class="subsubsub">';
					echo '<li style="margin-right:5px;"><a ' . esc_attr( $all ) . ' href="' . add_query_arg( 'status', 'all' ) . '">All <span style="color: #555;">(' . count( $all_users ) . ')</span></a> | </li>';
					echo '<li style="margin-right:5px;"><a ' . esc_attr( $active ) . ' href="' . add_query_arg( 'status', 'active' ) . '">Active <span style="color: #555;">(' . count( $active_users ) . ')</span></a> | </li>';
					echo '<li style="margin-right:5px;"><a ' . esc_attr( $inactive ) . ' href="' . add_query_arg( 'status', 'inactive' ) . '">Inactive <span style="color: #555;">(' . $inactive_users . ')</span></a></li>';
					echo '</ul>';
				}
			}
		}

		public function get_columns() {
			if ( $this->user_id == 0 ) {
				if ( class_exists( 'ZACCTMGR_Core' ) ) {
					$columns = array(
						'name'                 => 'Name',
						'username'             => 'Username',
						'leads'                => 'Leads',
						'bookmarks'            => 'Bookmarks',
						'search_functionality' => 'Search',
						'export_functionality' => 'Export',
						'search_request'       => 'Search Request',
						'basic_results'        => 'Basic Results',
						'advanced_results'     => 'Advanced Results',
						'actions'              => 'Actions',
					);
				} else {
					$columns = array(
						'name'                 => 'Name',
						'username'             => 'Username',
						'leads_created'        => 'Leads Created',
						'bookmarks'            => 'Bookmarks',
						'search_functionality' => 'Search',
						'export_functionality' => 'Export',
						'search_request'       => 'Search Request',
						'basic_results'        => 'Basic Results',
						'advanced_results'     => 'Advanced Results',
						'actions'              => 'Actions',
					);

				}
			} else if ( class_exists( 'ZACCTMGR_Core' ) ) {
				$columns = array(
					'name'                 => 'Name',
					'username'             => 'Username',
					'leads'                => 'Leads',
					'bookmarks'            => 'Bookmarks',
					'search_functionality' => 'Search',
					'export_functionality' => 'Export',
					'search_request'       => 'Search Request',
					'basic_results'        => 'Basic Results',
					'advanced_results'     => 'Advanced Results'
				);
			} else {
				$columns = array(
					'name'                 => 'Name',
					'username'             => 'Username',
					'leads_created'        => 'Leads Created',
					'bookmarks'            => 'Bookmarks',
					'search_functionality' => 'Search',
					'export_functionality' => 'Export',
					'search_request'       => 'Search Request',
					'basic_results'        => 'Basic Results',
					'advanced_results'     => 'Advanced Results'
				);
			}

			return $columns;

		}

		public function prepare_items() {
			global $wpdb;
			$table_name = $wpdb->prefix . 'zleadscrm_leads_user_analytics';


			if ( $this->user_id == 0 ) {
				$results = $wpdb->get_results( "SELECT user_id, SUM(basic_results) AS basic_results, SUM(advanced_results) AS advanced_results, SUM(basic_requests) AS search_request FROM $table_name GROUP BY user_id;" );

				$users = [];

				foreach ( $results as $result ) {
					$user                 = get_user_by( 'id', $result->user_id );
					$search_functionality = zleadscrm_user_can_do_advanced_search( $result->user_id ) == true ? 'Advanced' : ( zleadscrm_user_can_do_basic_search( $result->user_id ) == true ? 'Basic' : 'No Rights' );
					if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
						$export_functionality = zleadscrm_user_can_export_search( $result->user_id ) == true ? 'yes' : 'no';
					} else {
						$export_functionality = 'no';
					}
					$bookmarks = zleadscrm_get_number_of_bookmarks( $user->ID );
					if ( class_exists( 'ZACCTMGR_Core' ) ) {
						$leads         = zleadscrm_get_number_of_leads( $user->ID );
						$leads_created = 0;
					} else {
						$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
						$leads         = 0;
					}
					array_push( $users, array(
						'name'                 => $user->last_name . ', ' . $user->first_name,
						'username'             => $user->user_login,
						'leads'                => $leads,
						'leads_created'        => $leads_created,
						'search_functionality' => $search_functionality,
						'export_functionality' => $export_functionality,
						'search_request'       => $result->search_request,
						'basic_results'        => $result->basic_results,
						'advanced_results'     => $result->advanced_results,
						'user_id'              => $result->user_id,
						'bookmarks'            => $bookmarks
					) );
				}

				$selected_roles = zleadscrm_get_selected_roles();
				$inactive_users = [];

				$query = new WP_User_Query( array(
					'role__in' => $selected_roles
				) );

				$all_users = $query->get_results();

				foreach ( $all_users as $user ) {
					if ( ! exist_in_array( $users, $user ) ) {
						$search_functionality = zleadscrm_user_can_do_advanced_search( $user->ID ) == true ? 'Advanced' : ( zleadscrm_user_can_do_basic_search( $user->ID ) == true ? 'Basic' : 'No Rights' );
						if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
							$export_functionality = zleadscrm_user_can_export_search( $user->ID ) == true ? 'yes' : 'no';
						} else {
							$export_functionality = 'no';
						}
						$bookmarks = zleadscrm_get_number_of_bookmarks( $user->ID );
						if ( class_exists( 'ZACCTMGR_Core' ) ) {
							$leads         = zleadscrm_get_number_of_leads( $user->ID );
							$leads_created = 0;
						} else {
							$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
							$leads         = 0;
						}
						array_push( $inactive_users, array(
							'name'                 => $user->last_name . ', ' . $user->first_name,
							'username'             => $user->user_login,
							'leads'                => $leads,
							'leads_created'        => $leads_created,
							'search_functionality' => $search_functionality,
							'export_functionality' => $export_functionality,
							'search_request'       => 0,
							'basic_results'        => 0,
							'advanced_results'     => 0,
							'user_id'              => $user->ID,
							'bookmarks'            => $bookmarks
						) );
					}
				}


				$status = isset( $_GET['status'] ) ? sanitize_text_field( $_GET['status'] ) : 'all';

				if ( $status == 'active' ) {
					$this->items = $users;
				} else if ( $status != 'all' ) {
					$this->items = $inactive_users;
				} else {
					$this->items = $users;
					foreach ( $inactive_users as $inactive_user ) {
						array_push( $this->items, $inactive_user );
					}
				}
			} else {
				$user = get_user_by( 'id', $this->user_id );
				if ( class_exists( 'ZACCTMGR_Core' ) ) {
					$leads         = zleadscrm_get_number_of_leads( $user->ID );
					$leads_created = 0;
				} else {
					$leads_created = zleadscrm_get_number_of_leads_created( $user->ID );
					$leads         = 0;
				}
				$results = $wpdb->get_results( "SELECT user_id, SUM(basic_results) AS basic_results, SUM(advanced_results) AS advanced_results, SUM(basic_requests) AS search_request FROM $table_name WHERE user_id=$this->user_id GROUP BY user_id;" );

				if ( class_exists( 'ZLEADSCRM_EXPORT_Core' ) ) {
					$export_functionality = zleadscrm_user_can_export_search( $user->ID ) == true ? 'yes' : 'no';
				} else {
					$export_functionality = 'no';
				}
				$bookmarks            = zleadscrm_get_number_of_bookmarks( $user->ID );
				$search_functionality = zleadscrm_user_can_do_advanced_search( $user->ID ) == true ? 'Advanced' : ( zleadscrm_user_can_do_basic_search( $user->ID ) == true ? 'Basic' : 'No Rights' );
				if ( count( $results ) != 0 ) {
					$search_request   = $results[0]->search_request;
					$basic_results    = $results[0]->basic_results;
					$advanced_results = $results[0]->advanced_results;
				} else {
					$search_request   = 0;
					$basic_results    = 0;
					$advanced_results = 0;
				}


				$this->items = array(
					array(
						'name'                 => $user->last_name . ', ' . $user->first_name,
						'username'             => $user->user_login,
						'leads'                => $leads,
						'leads_created'        => $leads_created,
						'search_functionality' => $search_functionality,
						'export_functionality' => $export_functionality,
						'search_request'       => $search_request,
						'basic_results'        => $basic_results,
						'advanced_results'     => $advanced_results,
						'user_id'              => $user->ID,
						'bookmarks'            => $bookmarks
					)
				);
			}

			/**
			 * Init column headers.
			 */
			$this->_column_headers = array( $this->get_columns(), array(), array() );


		}

	}

	function exist_in_array( $array, $user ) {
		foreach ( $array as $arr ) {
			if ( ( $arr['username'] == $user->user_login ) ) {
				return true;
			}
		}

		return false;
	}

?>